==> goods-center-biz-1.7.7-20161212.040916-1-sources.jar: cn/com/duiba/goods/center/biz/entity/ItemLimitEntity.java <==
package cn.com.duiba.goods.center.biz.entity;

import java.util.Date;

public class ItemLimitEntity {

	public static final String SOURCETYP_EORDER = "order"; // 主订单

	private Long id;
	private Long consumerId;
	private Long appId;
	private Long appItemId;
	private Long itemId;
	private String itemKey;
	private String subKey;
	private Long sourceId;
	private String sourceType;
	private Date gmtCreate;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public void setItemKey(String itemKey) {
		this.itemKey = itemKey;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public String getItemKey() {
		return itemKey;
	}

	public void setItemKey(Long itemId, Long appItemId) {
		String devItemId = appItemId == null ? "" : String.valueOf(appItemId);
		String duibaItemId = itemId == null ? "" : String.valueOf(itemId);
		String key = devItemId + "_" + duibaItemId;
		this.itemKey = key;
	}

	public static String getItemKey(Long itemId, Long appItemId) {
		String devItemId = appItemId == null ? "" : String.valueOf(appItemId);
		String duibaItemId = itemId == null ? "" : String.valueOf(itemId);
		return devItemId + "_" + duibaItemId;
	}

	public String getSubKey() {
		return subKey;
	}

	public void setSubKey(String subKey) {
		this.subKey = subKey;
	}

	public Long getSourceId() {
		return sourceId;
	}

	public void setSourceId(Long sourceId) {
		this.sourceId = sourceId;
	}

	public String getSourceType() {
		return sourceType;
	}

	public void setSourceType(String sourceType) {
		this.sourceType = sourceType;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

}

==> goods-center-biz-1.8.5-20170111.123239-1-sources.jar: cn/com/duiba/goods/center/biz/entity/ItemLimitEntity.java <==
package cn.com.duiba.goods.center.biz.entity;

import java.util.Date;

/**
 * 
 * ItemLimitEntity
 *
 */
public class ItemLimitEntity {

	public static final String SOURCETYP_EORDER = "order"; // 主订单

	private Long id;
	private Long consumerId;
	private Long appId;
	private Long appItemId;
	private Long itemId;
	private String itemKey;
	private String subKey;
	private Long sourceId;
	private String sourceType;
	private Date gmtCreate;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public void setItemKey(String itemKey) {
		this.itemKey = itemKey;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public String getItemKey() {
		return itemKey;
	}

	/**
	 * setItemKey
	 * @param itemId
	 * @param appItemId
	 */
	public void setItemKey(Long itemId, Long appItemId) {
		String devItemId = appItemId == null ? "" : String.valueOf(appItemId);
		String duibaItemId = itemId == null ? "" : String.valueOf(itemId);
		String key = devItemId + "_" + duibaItemId;
		this.itemKey = key;
	}

	/**
	 * getItemKey
	 * @param itemId
	 * @param appItemId
	 * @return
	 */
	public static String getItemKey(Long itemId, Long appItemId) {
		String devItemId = appItemId == null ? "" : String.valueOf(appItemId);
		String duibaItemId = itemId == null ? "" : String.valueOf(itemId);
		return devItemId + "_" + duibaItemId;
	}

	public String getSubKey() {
		return subKey;
	}

	public void setSubKey(String subKey) {
		this.subKey = subKey;
	}

	public Long getSourceId() {
		return sourceId;
	}

	public void setSourceId(Long sourceId) {
		this.sourceId = sourceId;
	}

	public String getSourceType() {
		return sourceType;
	}

	public void setSourceType(String sourceType) {
		this.sourceType = sourceType;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

}
